@@ -3,13 +3,13 @@ from __future__ import annotations
 import contextlib
 from enum import IntEnum, IntFlag, auto
 from functools import partial
-from typing import Any, Iterable, overload
+from typing import TYPE_CHECKING, Any, overload
 
-from qtpy.QtCore import QPoint, QSize, Qt, Signal
+from qtpy import QtGui
+from qtpy.QtCore import Property, QPoint, QSize, Qt, Signal
 from qtpy.QtGui import QFontMetrics, QValidator
 from qtpy.QtWidgets import (
     QAbstractSlider,
-    QApplication,
     QBoxLayout,
     QDoubleSpinBox,
     QHBoxLayout,
@@ -25,6 +25,9 @@ from superqt.utils import signals_blocked
 
 from ._sliders import QDoubleRangeSlider, QDoubleSlider, QRangeSlider
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable
+
 
 class LabelPosition(IntEnum):
     NoLabel = 0
@@ -32,6 +35,7 @@ class LabelPosition(IntEnum):
     LabelsBelow = auto()
     LabelsRight = LabelsAbove
     LabelsLeft = LabelsBelow
+    LabelsOnHandle = auto()
 
 
 class EdgeLabelMode(IntFlag):
@@ -43,10 +47,10 @@ class EdgeLabelMode(IntFlag):
 class _SliderProxy:
     _slider: QSlider
 
-    def value(self) -> int:
+    def value(self) -> Any:
         return self._slider.value()
 
-    def setValue(self, value: int) -> None:
+    def setValue(self, value: Any) -> None:
         self._slider.setValue(value)
 
     def sliderPosition(self) -> int:
@@ -158,6 +162,9 @@ def _handle_overloaded_slider_sig(
 
 class QLabeledSlider(_SliderProxy, QAbstractSlider):
     editingFinished = Signal()
+    _ivalueChanged = Signal(int)
+    _isliderMoved = Signal(int)
+    _irangeChanged = Signal(int, int)
 
     _slider_class = QSlider
     _slider: QSlider
@@ -257,8 +264,6 @@ class QLabeledSlider(_SliderProxy, QAbstractSlider):
             self.layout().setContentsMargins(0, 0, 0, 0)
         self._on_slider_range_changed(self.minimum(), self.maximum())
 
-        QApplication.processEvents()
-
     # putting this after labelMode methods for the sake of mypy
     EdgeLabelMode = EdgeLabelMode
 
@@ -279,8 +284,9 @@ class QLabeledSlider(_SliderProxy, QAbstractSlider):
         self._slider.setValue(int(value))
 
     def _rename_signals(self) -> None:
-        # for subclasses
-        pass
+        self.valueChanged = self._ivalueChanged
+        self.sliderMoved = self._isliderMoved
+        self.rangeChanged = self._irangeChanged
 
 
 class QLabeledDoubleSlider(QLabeledSlider):
@@ -386,10 +392,10 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
         """Set where/whether labels are shown adjacent to slider handles."""
         self._handle_label_position = opt
         for lbl in self._handle_labels:
-            if not opt:
-                lbl.hide()
-            else:
-                lbl.show()
+            lbl.setVisible(bool(opt))
+            trans = opt == LabelPosition.LabelsOnHandle
+            # TODO: make double clickable to edit
+            lbl.setAttribute(Qt.WidgetAttribute.WA_TransparentForMouseEvents, trans)
         self.setOrientation(self.orientation())
 
     def edgeLabelMode(self) -> EdgeLabelMode:
@@ -415,7 +421,6 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
         elif opt == EdgeLabelMode.LabelIsRange:
             self._min_label.setValue(self._slider.minimum())
             self._max_label.setValue(self._slider.maximum())
-        QApplication.processEvents()
         self._reposition_labels()
 
     def setRange(self, min: int, max: int) -> None:
@@ -434,6 +439,7 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
         """Set orientation, value will be 'horizontal' or 'vertical'."""
         self._slider.setOrientation(orientation)
         inverted = self._slider.invertedAppearance()
+        marg = (0, 0, 0, 0)
         if orientation == Qt.Orientation.Vertical:
             layout: QBoxLayout = QVBoxLayout()
             layout.setSpacing(1)
@@ -441,9 +447,7 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
             # TODO: set margins based on label width
             if self._handle_label_position == LabelPosition.LabelsLeft:
                 marg = (30, 0, 0, 0)
-            elif self._handle_label_position == LabelPosition.NoLabel:
-                marg = (0, 0, 0, 0)
-            else:
+            elif self._handle_label_position == LabelPosition.LabelsRight:
                 marg = (0, 0, 20, 0)
             layout.setAlignment(Qt.AlignmentFlag.AlignCenter)
         else:
@@ -451,9 +455,7 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
             layout.setSpacing(7)
             if self._handle_label_position == LabelPosition.LabelsBelow:
                 marg = (0, 0, 0, 25)
-            elif self._handle_label_position == LabelPosition.NoLabel:
-                marg = (0, 0, 0, 0)
-            else:
+            elif self._handle_label_position == LabelPosition.LabelsAbove:
                 marg = (0, 25, 0, 0)
             self._add_labels(layout, inverted=inverted)
 
@@ -465,14 +467,13 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
         self.setLayout(layout)
         layout.setContentsMargins(*marg)
         super().setOrientation(orientation)
-        QApplication.processEvents()
         self._reposition_labels()
 
     def setInvertedAppearance(self, a0: bool) -> None:
         self._slider.setInvertedAppearance(a0)
         self.setOrientation(self._slider.orientation())
 
-    def resizeEvent(self, a0) -> None:
+    def resizeEvent(self, a0: Any) -> None:
         super().resizeEvent(a0)
         self._reposition_labels()
 
@@ -480,6 +481,15 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
     LabelPosition = LabelPosition
     EdgeLabelMode = EdgeLabelMode
 
+    def _getBarColor(self) -> QtGui.QBrush:
+        return self._slider._style.brush(self._slider._styleOption)
+
+    def _setBarColor(self, color: str) -> None:
+        self._slider._style.brush_active = color
+
+    barColor = Property(QtGui.QBrush, _getBarColor, _setBarColor)
+    """The color of the bar between the first and last handle."""
+
     # ------------- private methods ----------------
     def _rename_signals(self) -> None:
         self.valueChanged = self._valueChanged
@@ -495,6 +505,7 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
 
         horizontal = self.orientation() == Qt.Orientation.Horizontal
         labels_above = self._handle_label_position == LabelPosition.LabelsAbove
+        labels_on_handle = self._handle_label_position == LabelPosition.LabelsOnHandle
 
         last_edge = None
         labels: Iterable[tuple[int, SliderLabel]] = enumerate(self._handle_labels)
@@ -502,13 +513,18 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
             labels = reversed(list(labels))
         for i, label in labels:
             rect = self._slider._handleRect(i)
-            dx = -label.width() / 2
+            dx = (-label.width() / 2) + 2
             dy = -label.height() / 2
-            if labels_above:
+            if labels_above:  # or on the right
                 if horizontal:
                     dy *= 3
                 else:
                     dx *= -1
+            elif labels_on_handle:
+                if horizontal:
+                    dy += 0.5
+                else:
+                    dx += 0.5
             else:
                 if horizontal:
                     dy *= -1
@@ -525,6 +541,7 @@ class QLabeledRangeSlider(_SliderProxy, QAbstractSlider):
             label.move(pos)
             last_edge = pos
             label.clearFocus()
+            label.raise_()
             label.show()
         self.update()
 
@@ -612,6 +629,15 @@ class QLabeledDoubleRangeSlider(QLabeledRangeSlider):
         for lbl in self._handle_labels:
             lbl.setDecimals(prec)
 
+    def _getBarColor(self) -> QtGui.QBrush:
+        return self._slider._style.brush(self._slider._styleOption)
+
+    def _setBarColor(self, color: str) -> None:
+        self._slider._style.brush_active = color
+
+    barColor = Property(QtGui.QBrush, _getBarColor, _setBarColor)
+    """The color of the bar between the first and last handle."""
+
 
 class SliderLabel(QDoubleSpinBox):
     def __init__(
